@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2022
+## Copyright (C) 2016-2024
 ##
 ## This file is part of the R package splines2.
 ##
@@ -23,7 +23,7 @@
 ##' \item M-splines
 ##' \item I-splines
 ##' \item convex splines (C-splines)
-##' \item periodic M-splines
+##' \item periodic splines
 ##' \item natural cubic splines
 ##' \item generalized Bernstein polynomials
 ##' \item along with their integrals (except C-splines) and derivatives
@@ -51,6 +51,7 @@
 ##' @importFrom Rcpp sourceCpp
 ##' @useDynLib splines2
 ##'
-##' @docType package
 ##' @name splines2
-NULL
+##' @aliases splines2-package
+##' @keywords internal
+"_PACKAGE"
